@@ -1,6 +1,5 @@
-
 # Copyright (c) 2022, CovidPyLib
-# This file is part of CovidPy v0.0.8.
+# This file is part of CovidPy v0.1.0.
 #
 # The project has been distributed in the hope it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -8,8 +7,9 @@
 #
 # You can use it and/or modify it under the terms of the GNU General Public License v3.0 or later.
 # You should have received a copy of the GNU General Public License along with the project.
-
 from .lib import CovidPy
-from .types import QRCode, VerifyResult
+from .types import *
 from .verifier import DCCVerifier
-from .errors import InvalidDCC
\ No newline at end of file
+from .errors import InvalidDCC
+
+__version__ = "0.1.0"
